%{!?dotests:%define DO_TESTS 1}

%define _libdir64 %{_libdir}64

Summary:	Font configuration and customization library
Name:		fontconfig
Version:	2.14.2
Release:	1
License:	MIT
Group:		System Environment/Libraries
Source:		https://www.freedesktop.org/software/fontconfig/release/%{name}-%{version}.tar.gz
URL:		https://fontconfig.org/
Requires:	freetype2 >= 2.12.1
Requires:       expat >= 2.5.0
Requires:       gettext >= 0.21
%if %{toolchain} == "gcc"
Requires: libgcc >= 10
%endif

BuildRequires:	freetype2-devel >= 2.12.1
BuildRequires:  expat-devel >= 2.5.0
BuildRequires:  gperf >= 3.1


%description
Fontconfig is designed to locate fonts within the system and select them
according to requirements specified by applications.

The library is available as 32-bit and 64-bit.

%package devel
Summary:	Font configuration and customization library
Group:		Development/Libraries
Requires:	%{name} = %{version}
Requires:	freetype2-devel >= 2.12.1
Requires:  	expat-devel >= 2.5.0

%description devel
The fontconfig-devel package includes the header files, and developer docs
for the fontconfig package.
Install fontconfig-devel if you want to develop programs which will use
fontconfig.

%prep
echo "DO_TESTS=%{DO_TESTS}"
%setup -q

# Duplicate source for 32 & 64 bits
rm -rf /tmp/%{name}-%{version}-32bit
mkdir  /tmp/%{name}-%{version}-32bit
mv *   /tmp/%{name}-%{version}-32bit
mkdir 32bit
mv     /tmp/%{name}-%{version}-32bit/* 32bit
rm -rf /tmp/%{name}-%{version}-32bit
mkdir 64bit
cp -rp 32bit/* 64bit/

%build
# first build the 64-bit version
cd 64bit
export OBJECT_MODE=64
export CC="%{__cc__}  -maix64 -pthread "
export CFLAGS="-O2 -I/opt/freeware/include -I/usr/local/include"
export CXX="%__cxx__} -maix64 -pthread" 
export CXXFLAGS="-O2 -I/opt/freeware/include -I/usr/local/include" 
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static

gmake %{?_smp_mflags} V=1

if [ "%{DO_TESTS}" == 1 ]
then
    ( ulimit -m unlimited; ulimit -d unlimited;gmake -k check || true )
    /usr/sbin/slibclean
fi

# now build the 32-bit version
cd ../32bit
export OBJECT_MODE=32
export CC="%{__cc__}  -maix32 -pthread" 
export CFLAGS="-O2 -I/opt/freeware/include -I/usr/local/include" 
export CXX="%{__cxx__} -maix32 -pthread" 
export CXXFLAGS="-O2 -I/opt/freeware/include -I/usr/local/include" 
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static

gmake %{?_smp_mflags} V=1

if [ "%{DO_TESTS}" == 1 ]
then
    ( gmake -k check || true ) 
    /usr/sbin/slibclean
fi

%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
export RM="/usr/bin/rm -f"
# setup environment for 32-bit and 64-bit builds
export AR="/usr/bin/ar -X32_64"
export NM="/usr/bin/nm -X32_64"

# install 64-bit version
export OBJECT_MODE=64
cd 64bit
gmake DESTDIR=$RPM_BUILD_ROOT install
cd ..

# extract 64-bit shared object files from 64 bit libs
cd ${RPM_BUILD_ROOT}%{_libdir64}
/usr/bin/ar -X64 xv libfontconfig.a  libfontconfig.so.1
cd -

# Rename executables
for f in ${RPM_BUILD_ROOT}%{_bindir}/* ; do
    mv ${f} ${f}_64
done

# install 32-bit version
export OBJECT_MODE=32
cd 32bit
gmake DESTDIR=$RPM_BUILD_ROOT install
cd ..

#Rename executables and make 64bit as default.
(
cd  ${RPM_BUILD_ROOT}/%{_prefix}/bin
for f in $(ls -1| grep -v -e _32 -e _64); do
    mv ${f} ${f}_32
    ln -sf "$f"_64 $f
done
)

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects and extract the 32 bit share objects
cd ${RPM_BUILD_ROOT}%{_libdir}
/usr/bin/ar -q -X64 libfontconfig.a  ${RPM_BUILD_ROOT}%{_libdir64}/libfontconfig.so.1

#remove 64bit shared obj
rm ${RPM_BUILD_ROOT}%{_libdir64}/libfontconfig.so.1

%files
%defattr(-,root,system)
%doc 32bit/README 32bit/AUTHORS 32bit/COPYING 
%doc %{_datadir}/doc/fontconfig/fontconfig-user.txt  
%{_prefix}/etc/fonts/*
%{_bindir}/fc*
%{_libdir}/*.a
%{_libdir64}/*.a
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_datadir}/xml/fontconfig

%files devel
%defattr(-,root,system)
%doc %{_datadir}/doc/fontconfig/fontconfig-devel.txt 
%{_libdir}/pkgconfig/*.pc
%{_libdir64}/pkgconfig/*.pc
%{_includedir}/fontconfig/*.h
%{_mandir}/man3/*
%{_datadir}/gettext/its/fontconfig.its
%{_datadir}/gettext/its/fontconfig.loc

%changelog
* Wed Dec 06 2023 Ranjit Ranjan <ranjit.ranjan@ibm.com> 2.14.2-1
- Update to 2.14.2.

* Fri May 03 2019 Reshma V Kumar <reskumar@in.ibm.com> 2.11.95-4
- Rebuild with expat 2.2.6

* Tue Jun 14 2016 Nitish K Mishra <nitismis@in.ibm.com> 2.11.95-2
- Update to 2.11.95-2

* Thu Jun 9 2016 Matthieu Sarter <matthieu.sarter.external@atos.net> 2.11.95-2
- Added the .so files

* Mon Apr 25 2016 Matthieu Sarter <matthieu.sarter.external@atos.net>  2.11.95-1
- Update to version 2.11.95

* Fri Sep 23 2011 Patricia Cugny <patricia.cugny@bull.net> 2.8.0-3
- rebuild for compatibility with new libiconv.a 1.13.1-2

*  Mon Jun 06 2011 Gerard Visiedo <gerard.visiedo àbull.net> 2.8.0-2
 - Compiling on 3é and 64 bits

*  Wed Nov 26 2010 Jean Noel Cordenner <jean-noel.cordenner@bull.net> 2.8.0-1
 - Update to version 2.8.0

*  Wed Nov 15 2006  BULL
 - Release 7 
 - gnome 2.16.1

*  Tue Sep 19 2006  BULL
 - Release 6
 - support 64 bit
*  Fri Dec 23 2005  BULL
 - Release 5
 - Prototype gtk 64 bit
*  Wed Nov 16 2005  BULL
 - Release  4
*  Mon May 30 2005  BULL
 - Release  3
 - .o removed from lib
*  Fri Sep 24 2004  BULL
 - Release  2
 - Package the directories /opt/freeware/etc/fonts, /opt/freeware/include/fontconfig and /usr/include/fontconfig along with their contents
